@@ -2,6 +2,10 @@
 
 tmpdir=$(mktemp -d)
 
+if [ ! -e /usr/share/color/icc/sRGB.icc ]; then
+    echo "ERROR: install icc-profiles-free first" >&2
+    exit 1
+fi
 
 # Download source file
 if [ -n "$1" ]; then
@@ -31,6 +35,9 @@ fi
 # Cleanup unwanted files
 rm -rf $srcdir/fonts/free*
 
+# Replace include/sRGB.icc
+cp /usr/share/color/icc/sRGB.icc $srcdir/include/sRGB.icc
+
 # Repack as tar.xz
 tar Jcf tcpdf_${version}.orig.tar.xz $srcdir
 
